// Load the dataset
const csvUrl =
  'https://gist.githubusercontent.com/Praveen-Banoth/75f286859449c45c0adb4402dca2ee95/raw/8bccedada91b04fac5ae9c85dd71c2af5d9c88b3/gistfile1.txt';

// Load the dataset and create the line chart
d3.csv(csvUrl, d3.autoType)
  .then((data) => {
    createLineChart(data, 'line-chart');
  })
  .catch((error) => {
    console.error('Error loading the data:', error);
  });

// Function to create a line chart
function createLineChart(data, containerId) {
  const width = 800;
  const height = 500;
  const margin = {
    top: 50,
    right: 150,
    bottom: 50,
    left: 50,
  };

  // Create SVG element
  const svg = d3
    .select(`#${containerId}`)
    .append('svg')
    .attr('width', width)
    .attr('height', height);

  // Extract unique team names
  const teams = Array.from(
    new Set(data.map((d) => d.Team)),
  );

  // Define color scale for lines
  const colorScale = d3
    .scaleOrdinal()
    .domain(teams)
    .range(d3.schemeCategory10);

  // Define scales for x and y axes
  const xScale = d3
    .scaleLinear()
    .domain([
      d3.min(data, (d) => d.Year),
      d3.max(data, (d) => d.Year),
    ])
    .range([margin.left, width - margin.right]);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Wins)])
    .range([height - margin.bottom, margin.top]);

  // Draw lines for each team
  teams.forEach((team) => {
    const teamData = data.filter((d) => d.Team === team);

    const line = d3
      .line()
      .x((d) => xScale(d.Year))
      .y((d) => yScale(d.Wins));

    svg
      .append('path')
      .datum(teamData)
      .attr('class', 'line')
      .attr('d', line)
      .attr('stroke', colorScale(team));
  });

  // Add x-axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0, ${height - margin.bottom})`,
    )
    .call(d3.axisBottom(xScale))
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.bottom - 10)
    .attr('fill', '#000')
    .attr('text-anchor', 'middle')
    .text('Year')
    .attr('class', 'axis-label');

  // Add y-axis
  svg
    .append('g')
    .attr('transform', `translate(${margin.left}, 0)`)
    .call(d3.axisLeft(yScale))
    .append('text')
    .attr('x', -margin.left)
    .attr('y', 10)
    .attr('fill', '#000')
    .attr('text-anchor', 'start')
    .text('Wins')
    .attr('class', 'axis-label');

  // Add legend
  const legend = svg
    .append('g')
    .attr(
      'transform',
      `translate(${width - margin.right + 20}, ${margin.top})`,
    );

  teams.forEach((team, i) => {
    legend
      .append('rect')
      .attr('x', 0)
      .attr('y', i * 20)
      .attr('width', 10)
      .attr('height', 10)
      .attr('fill', colorScale(team));

    legend
      .append('text')
      .attr('x', 15)
      .attr('y', i * 20 + 9)
      .text(team)
      .attr('class', 'legend');
  });
}
